Method: RGeo::Geos.preferred_native_interface

Defined in:
lib/rgeo/geos/interface.rb

.preferred_native_interfaceObject

The preferred native interface. This is the native interface used by default when a factory is created. Supported values are :capi and :ffi.

This is set automatically when RGeo loads, to :capi if the CAPI interface is available, otheriwse to :ffi if FFI is available, otherwise to nil if no GEOS interface is available. You can override this setting if you want to prefer FFI over CAPI.



85
86
87
# File 'lib/rgeo/geos/interface.rb', line 85

def preferred_native_interface
  @preferred_native_interface
end