Method: RGeo::Feature::Factory#multi_line_string

Defined in:
lib/rgeo/feature/factory.rb

#multi_line_string(_elems) ⇒ Object

Create a feature of type MultiLineString. The elems should be an Enumerable of objects that are or can be cast to LineString or any of its subclasses. Returns nil if any of the contained geometries is not a LineString, which would break the MultiLineString contract.

Although implementations are free to attempt to handle input objects that are not of this factory, strictly speaking, the result of building geometries from objects of the wrong factory is undefined.



200
201
202
# File 'lib/rgeo/feature/factory.rb', line 200

def multi_line_string(_elems)
  raise Error::UnsupportedOperation, "Method #{self.class}##{__method__} not defined."
end