Method: RGeo::Feature::Factory#multi_polygon

Defined in:
lib/rgeo/feature/factory.rb

#multi_polygon(_elems) ⇒ Object

Create a feature of type MultiPolygon. The elems should be an Enumerable of objects that are or can be cast to Polygon or any of its subclasses. Returns nil if any of the contained geometries is not a Polygon, which would break the MultiPolygon contract. Also returns nil if any of the other assertions for MultiPolygon are not met, e.g. if any of the polygons overlap.

Although implementations are free to attempt to handle input objects that are not of this factory, strictly speaking, the result of building geometries from objects of the wrong factory is undefined.



217
218
219
# File 'lib/rgeo/feature/factory.rb', line 217

def multi_polygon(_elems)
  raise Error::UnsupportedOperation, "Method #{self.class}##{__method__} not defined."
end