Method: RGeo::Feature::Geometry#spatial_dimension

Defined in:
lib/rgeo/feature/geometry.rb

#spatial_dimensionInteger

SFS 1.2 Description

The spatial dimension is the dimension of the spatial portion of the direct positions (coordinate tuples) used in the definition of this geometric object. If the direct positions do not carry a measure coordinate, this will be equal to the coordinate dimension.

Notes

Similar to coordinate_dimension except it will ignore the M component always.

Returns:

  • (Integer)

Raises:



136
137
138
# File 'lib/rgeo/feature/geometry.rb', line 136

def spatial_dimension
  raise Error::UnsupportedOperation, "Method #{self.class}#spatial_dimension not defined."
end