Method: RGeo::Feature::Geometry#distance
- Defined in:
- lib/rgeo/feature/geometry.rb
#distance(_another_geometry) ⇒ Object
SFS 1.1 Description
Returns the shortest distance between any two Points in the two geometric objects as calculated in the spatial reference system of this geometric object.
Notes
Returns a floating-point scalar value.
Although implementations are free to attempt to handle another_geometry values that do not share the same factory as this geometry, strictly speaking, the result of measuring the distance between objects from different factories is undefined.
501 502 503 |
# File 'lib/rgeo/feature/geometry.rb', line 501 def distance(_another_geometry) raise Error::UnsupportedOperation, "Method #{self.class}#distance not defined." end |